==> flowable-ui-task-rest-6.4.2-sources.jar: org/flowable/ui/task/rest/runtime/ProcessInstanceQueryResource.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.ui.task.rest.runtime;

import org.flowable.ui.common.model.ResultListDataRepresentation;
import org.flowable.ui.task.service.runtime.FlowableProcessInstanceQueryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import com.fasterxml.jackson.databind.node.ObjectNode;

@RestController
@RequestMapping("/app")
public class ProcessInstanceQueryResource {

    @Autowired
    protected FlowableProcessInstanceQueryService processInstanceQueryService;

    @RequestMapping(value = "/rest/query/process-instances", method = RequestMethod.POST, produces = "application/json")
    public ResultListDataRepresentation getProcessInstances(@RequestBody ObjectNode requestNode) {
        return processInstanceQueryService.getProcessInstances(requestNode);
    }

}

==> flowable-ui-task-rest-6.8.0-sources.jar: org/flowable/ui/task/rest/runtime/ProcessInstanceQueryResource.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.ui.task.rest.runtime;

import org.flowable.ui.common.model.ResultListDataRepresentation;
import org.flowable.ui.task.service.runtime.FlowableProcessInstanceQueryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.fasterxml.jackson.databind.node.ObjectNode;

@RestController
@RequestMapping("/app")
public class ProcessInstanceQueryResource {

    @Autowired
    protected FlowableProcessInstanceQueryService processInstanceQueryService;

    @PostMapping(value = "/rest/query/process-instances", produces = "application/json")
    public ResultListDataRepresentation getProcessInstances(@RequestBody ObjectNode requestNode) {
        return processInstanceQueryService.getProcessInstances(requestNode);
    }

}
